Backends
--------

Backend
^^^^^^^

.. automodule:: quasar.backend
   :members:


QuasarBackend
^^^^^^^^^^^^^
      
.. automodule:: quasar.quasar_backend
   :members:

QiskitBackend
^^^^^^^^^^^^^

.. automodule:: quasar.qiskit_backend
   :members:

CirqBackend
^^^^^^^^^^^

.. automodule:: quasar.cirq_backend
   :members:


